==> designer-common-1.0.10-20251126.022212-3-sources.jar: com/digiwin/athena/constant/modelDriven/BusinessDirEnum.java <==
package com.digiwin.athena.constant.modelDriven;

/**
 * @Author wang yan
 * @Description // 自动生成视图枚举
 * @Date 2023/11/7 16:47
 * @Param
 * @return
 **/
public enum BusinessDirEnum {

    BUSINESS("businessConstructor", "业务", "business-constructor", ""),
    MODEL("model", "模型设计", "model-design/", ""),
    DATA_VIEW("dataView", "查询方案", "data-view/", "dataViewItem"),
    PAGE_DESIGN("pageDesign", "界面设计", "page-design/", ""),
    EVENT("event", "事件", "event/", "eventItem"),
    SERVICE("service", "服务", "service-arrange/", "serviceItem"),
    MONITOR("detect","侦测", "detect/", "detectItem"),
    MODEL_DESIGN("modelDesign", "模型", "model-design/", ""),
    JOB("homeWork", "作业", "page-design/", ""),
    CUSTOMER_EVENT("eventBusiness", "自定义", "", "eventItem"),
    ALL("all","所有","",""),
    // 服务编排和行动类型
    SERVICE_ARRANGE("arrange", "服务", "service/", "arrange"),
    SERVICE_ACTION("action", "行动", "service/", "action"),
    BUSINESS_PROCESS("businessProcess", "流程设计", "business-process/", "businessProcessItem"),


    DATA_ENTRY_RULE("rule", "规则列表", "", "/rule"),
    DATA_ENTRY_DESIGN("design", "界面设计", "", "/design"),
    DATA_ENTRY_BROWSE("browse", "浏览界面", "", "/browse"),
    DATA_ENTRY_BROWSE_FOR_API("browse", "浏览界面", "", "/browse-api"),
    DATA_ENTRY_EDIT("edit", "编辑界面", "", "/edit");



    // 和上面的type对应
    public static final String BUSINESS_CONSTRUCTOR_CODE = "businessConstructor";
    public static final String MODEL_CODE = "model";
    public static final String DATA_VIEW_CODE = "dataView";
    public static final String PAGE_DESIGN_CODE = "pageDesign";
    public static final String EVENT_CODE = "event";
    public static final String SERVICE_CODE = "service";
    public static final String BUSINESS_PROCESS_CODE = "businessProcess";
    public static final String MONITOR_CODE = "detect";
    public static final String MODEL_DESIGN_CODE = "modelDesign";
    public static final String JOB_CODE = "homeWork";
    public static final String JOB_MODEL_CODE = "homeWorkBusiness";
    public static final String DATA_VIEW_CODE_CODE = "dataViewBusiness";

    // 事件操作新建/编辑/删除
    public static final String OPERATE_CREATE = "create";
    public static final String OPERATE_EDIT = "edit";
    public static final String OPERATE_DELETE = "delete";

    private String type;
    private String name;
    private String path;
    private String subPath;

    BusinessDirEnum(String type, String name, String path, String subPath) {
        this.type = type;
        this.name = name;
        this.path = path;
        this.subPath = subPath;
    }

    public String getType() {
        return type;
    }

    public String getPath() {
        return path;
    }

    public String getName() {
        return name;
    }

    public String getSubPath() {
        return subPath;
    }


}

==> designer-common-1.0.10-20251218.080202-36-sources.jar: com/digiwin/athena/constant/modelDriven/BusinessDirEnum.java <==
package com.digiwin.athena.constant.modelDriven;

/**
 * @Author wang yan
 * @Description // 自动生成视图枚举
 * @Date 2023/11/7 16:47
 * @Param
 * @return
 **/
public enum BusinessDirEnum {

    BUSINESS("businessConstructor", "业务", "business-constructor", ""),
    MODEL("model", "模型设计", "model-design/", ""),
    DATA_VIEW("dataView", "查询方案", "data-view/", "dataViewItem"),
    PAGE_DESIGN("pageDesign", "界面设计", "page-design/", ""),
    EVENT("event", "事件", "event/", "eventItem"),
    SERVICE("service", "服务", "service-arrange/", "serviceItem"),
    MONITOR("detect","侦测", "detect/", "detectItem"),
    MODEL_DESIGN("modelDesign", "模型", "model-design/", ""),
    JOB("homeWork", "作业", "page-design/", ""),
    CUSTOMER_EVENT("eventBusiness", "自定义", "", "eventItem"),
    ALL("all","所有","",""),
    // 服务编排和行动类型
    SERVICE_ARRANGE("arrange", "服务", "service/", "arrange"),
    SERVICE_ACTION("action", "行动", "service/", "action"),
    BUSINESS_PROCESS("businessProcess", "流程设计", "business-process/", "businessProcessItem"),


    DATA_ENTRY_RULE("rule", "规则列表", "", "/rule"),
    DATA_ENTRY_DESIGN("design", "界面设计", "", "/design"),
    DATA_ENTRY_BROWSE("browse", "浏览界面", "", "/browse"),
    DATA_ENTRY_BROWSE_FOR_API("browse", "浏览界面", "", "/browse-api"),
    DATA_ENTRY_EDIT("edit", "编辑界面", "", "/edit"),

    PROJECT("project", "项目", "", "");

    // 和上面的type对应
    public static final String BUSINESS_CONSTRUCTOR_CODE = "businessConstructor";
    public static final String MODEL_CODE = "model";
    public static final String DATA_VIEW_CODE = "dataView";
    public static final String PAGE_DESIGN_CODE = "pageDesign";
    public static final String EVENT_CODE = "event";
    public static final String SERVICE_CODE = "service";
    public static final String BUSINESS_PROCESS_CODE = "businessProcess";
    public static final String MONITOR_CODE = "detect";
    public static final String MODEL_DESIGN_CODE = "modelDesign";
    public static final String JOB_CODE = "homeWork";
    public static final String JOB_MODEL_CODE = "homeWorkBusiness";
    public static final String DATA_VIEW_CODE_CODE = "dataViewBusiness";

    // 事件操作新建/编辑/删除
    public static final String OPERATE_CREATE = "create";
    public static final String OPERATE_EDIT = "edit";
    public static final String OPERATE_DELETE = "delete";

    private String type;
    private String name;
    private String path;
    private String subPath;

    BusinessDirEnum(String type, String name, String path, String subPath) {
        this.type = type;
        this.name = name;
        this.path = path;
        this.subPath = subPath;
    }

    public String getType() {
        return type;
    }

    public String getPath() {
        return path;
    }

    public String getName() {
        return name;
    }

    public String getSubPath() {
        return subPath;
    }


}
